// Example 1
// DESCRIPTION
clear all
cd $stpm3course\data
set scheme fpsaus_c

// Load Data
use rott3, clear


// Kaplan-Meier plot
sts graph, by(hormon) risktable

// Fit a Cox model
stcox i.hormon
estimates store stcox

// Fit a flexible parametric survival model
stpm3 i.hormon, scale(lncumhazard) df(3)
estimates store stpm3

// compare hazard ratios
estimates table stcox stpm3, eq(1:1) keep(1.hormon) eform se

// stpm3 has created spline variables
list _ns* _dns* in 1/10, noobs
line _ns* _t, sort name(_ns, replace) 
// You can ignore these!


// predict survival function
predict S0 S1, survival timevar(0 10, step(0.1)) ci ///
               frame(surv, replace)                 ///
               at1(hormon 0) at2(hormon 1)

// look at what frames we have
frame dir
              
               
// list values in frame               
frame surv: list in 1/11, noobs


// plot survival function
frame surv {
  twoway (line S0 S1 tt),                 ///
         xtitle("Years from diagnosis")   ///
         ytitle("S(t)")                   ///
         ylabel(0(0.2)1, format(%3.1f))   ///
         legend(order(1 "Not treated"     ///
                      2 "Treated"))       ///
         name(survival, replace)
}

// predict hazard rates
predict h0 h1, hazard timevar(0 10, step(0.1)) ci ///
               frame(hazard,replace) per(1000)    ///
               at1(hormon 0) at2(hormon 1)

// plot hazard rates
frame hazard {
  twoway (line h0 h1 tt),                      ///
         xtitle("Years from diagnosis")        ///
         ytitle("Mortality rate (per 1000py)") ///
         ylabel(0(20)160)                      ///
         legend(order(1 "Not treated"          ///
                      2 "Treated"))            ///
         name(hazard, replace)
}


// If I calculate h1/h0, what will I get?
frame hazard: gen hr = h1/h0
frame hazard: summ hr


// We have fitted a proportional hazards model,
// so hazards are perfectly proportional.
               
// Compare survival with Kaplan-Meier estimates
sts graph, by(hormon) 
frame surv: addplot: (line S0 S1 tt, pstyle(p1line p2line) ///
                                     lpattern(dash..)), ///
                                     legend(order(1 2))
               

// adjusting for confounders (under PH)
stpm3 i.hormon enodes age, scale(lncumhazard) df(3)
estimates store stpm3
stcox i.hormon enodes age
est store stcox
estimates table stcox stpm3, eq(1:1)  eform se
            
// look at some marginal comparisons            
estimates restore stpm3
stpm3km               
stpm3km   age               
stpm3km   nodes               
               