// Interactions

clear all
set scheme fpsaus_c
global dofile breast_nw_interactions.do

use breast_NW if inlist(dep,1,5)
stset survtime, f(dead=1) exit(time 5)

stpm3 @ns(agediag,df(3)) i.dep, scale(lncumhazard) df(4) nolog neq(1)
estimates store main

global hr_dep_main = exp(_b[5.dep])

stpm3 @ns(agediag,df(3))##i.dep, scale(lncumhazard) df(4) nolog neq(1) vsquish
estimates store inter

lrtest main inter


// survival for selected ages
estimates restore main
predict h30m h50m  h70m, surv ci timevar(0 5,step(0.1))              ///
                         frame(haz, replace)                         ///
                         at1(agediag 30 dep 1) at2(agediag 50 dep 1) ///
                         at3(agediag 70 dep 1) 
estimate restore inter
predict h30i  h50i h70i, surv ci                                     ///
                         frame(haz, merge)                           ///
                         at1(agediag 30 dep 1) at2(agediag 50 dep 1) ///
                         at3(agediag 70 dep 1) 


frame haz {                                  
  twoway (line h30m h50m h70m tt) ///
         (line h30i h50i h70i tt, /// 
               pstyle(p1line p2line p3line p4line p5line) ///
               lpattern(dash..))       ///
         ,xtitle("Years from surgery") ///
         ytitle("Proportion alive")   ///
         ylabel(0.5(0.1)1,format(%3.1f)) ///
         legend(order(1 "Age 30" 2 "Age 50" 3 "Age 70")) ///
         caption("Dashes lines are from interaction model", size(small)) ///
         note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))
}          

// HR for deprivation is a function of age for model with interaction
// We have proportional hazard and can choose any time to calculate HR
// I choose 1 year.
frame create ageHR
frame ageHR {
  range agediag 30 80 51
  gen dep = .
  predict h1 h5, hazard timevar(1) ci merge      ///
                 at1(dep 1, obsvalues)           ///
                 at2(dep 5, obsvalues)           ///
                 contrast(ratio) contrastvar(hr) 
}

frame ageHR {
  twoway (rarea hr_lci hr_uci agediag, color(%30))                        ///
         (line hr agediag, pstyle(p1line))                                ///
         , yline(${hr_dep_main}, lpattern(shortdash) lcolor(black))       ///
         legend(off)                                                      ///
         xtitle("Age at diagnosis (years)")                               ///
         ytitle("Hazard ratio")                                           ///
         note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))
         
}  


// We can also look at survival at 5 years as a function of age
frame create S5pred 
frame S5pred {
  range agediag 18 99 82
  gen dep = .
  gen t5 = 5
  estimates restore main
  predict S5dep1m S5dep5m, survival ci merge timevar(t5)    ///
                           at1(dep 1, obsvalues) at2(dep 5, obsvalues) 
  estimates restore inter
  predict S5dep1i S5dep5i, survival ci merge timevar(t5)    ///
                           at1(dep 1, obsvalues) at2(dep 5, obsvalues)                            
}    

frame S5pred {
  twoway (line S5dep1i S5dep5i agediag)                                            ///
         (rarea S5dep1i_lci S5dep1i_uci agediag, pstyle(p1line) color(%30))        ///
         (rarea S5dep5i_lci S5dep5i_uci agediag, pstyle(p2line) color(%30))        ///
         (line S5dep1m S5dep5m agediag, pstyle(p1line p2line) lpattern(dash dash)) ///
         , xtitle("Age at diagnosis")                                              ///
         ytitle("5-year survival")                                                 ///
         ylabel(,format(%3.1f))                                                    ///
         legend(off)                                                               ///
         caption("Dashes lines are from main effects model", size(small)) ///
         note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))
}                
             
             
            

  
// HR for age will have two curves for model with interaction.
// One for each deprivation group.
// make age 60 the reference age
frame ageHR {
  predict, hazard timevar(tt) ci merge nogen           ///
           at1(agediag 60 dep 1) at2(dep 1, obsvalues) ///
           contrast(ratio) contrastvar(hr_dep1)
           
  predict, hazard timevar(tt) ci merge nogen           ///
           at1(agediag 60 dep 5) at2(dep 5, obsvalues) ///
           contrast(ratio) contrastvar(hr_dep5)        
}

frame ageHR {
  twoway (rarea hr_dep1_lci hr_dep1_uci agediag, color(%30))                ///
         (line hr_dep1 agediag, pstyle(p1line))                             ///
         (rarea hr_dep5_lci hr_dep5_uci agediag, pstyle(p2line) color(%30)) ///
         (line hr_dep5 agediag, pstyle(p2line))                             ///
         , legend(order(2 "Least deprived" 4 "Most deprived"))              ///
         xtitle("Age at diagnosis (years)")                                 ///
         ytitle("Hazard ratio")                                             ///
         note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))

}
  
// Now see impact of interaction on marginal survival and difference?
range tt 0 5 101
estimates restore main
standsurv S1m S5m, surv timevar(tt) ci frame(surv, replace) ///
                 at1(dep 1) at2(dep 5)                      ///
                 contrast(difference) contrastvar(Sdiff_m)

estimates restore inter  
standsurv S1i S5i, surv ci frame(surv, merge)               ///
                 at1(dep 1) at2(dep 5)                      ///
                 contrast(difference) contrastvar(Sdiff_i)
                 
frame surv {
  twoway (line S1m S1i tt, pstyle(p1line..) lpattern(solid dash)) ///
         (line S5m S5i tt, pstyle(p2line..) lpattern(solid dash)) ///
         , xtitle("Years from diagnosis")                         ///
           ytitle("Standardized survival")                        ///
           legend(order(1 "Least deprived" 3 "Most deprived"))    ///
           caption("Dashes lines are from interaction model", size(small)) ///
           note("Graph code in ${dofile}", size(vsmall) span color(gs3%50)) ///
           name(Sstand,replace)
}                 

                 
frame surv {
  twoway (rarea Sdiff_m_lci Sdiff_m_uci tt, color(%30))                     ///
         (line  Sdiff_m tt, pstyle(p1line))                                 ///
         (line  Sdiff_i* tt, pstyle(p2line..) lpattern(solid dash dash))    ///
          ,xtitle("Years from diagnosis")                                   ///
           ytitle("Difference in standardized survival")                    ///
           legend(order(2 "Main effects model" 3 "Interaction model"))      ///
           note("Graph code in ${dofile}", size(vsmall) span color(gs3%50)) ///
           name(Sstand_diff,replace)

}                 

graph combine Sstand Sstand_diff, nocopies

  
