// Various predictions after fitting stpm3 model

clear all
set scheme fpsaus_c
global dofile stpm3_predictions



use breast_EW50 

stset survtime, failure(dead==1) exit(time 5)

stpm3 i.dep agediag, scale(lncumhazard) df(5) eform nolog


predict s, survival
twoway (scatter s _t, mcolor(%20) msize(vsmall) mlwidth(none)),  ///
        ylabel(,format(%3.1f))                                   ///
        xtitle("Years from diagnosis")                           ///
        ytitle("S(t)")                                           ///
        note("Graph code in ${dofile}",                          ///
              size(vsmall) span color(gs3%50))
       

gen t1 = 1
gen t5 = 5
predict S1 S5, surv frame(Spred1_5, replace) ///
               at1(., attimevar(t1))         ///
               at2(., attimevar(t5))

frame Spred1_5 {
  hist S1, name(S1, replace) title("1 year") xlab(,format(%3.1f)) wid(0.005)
  hist S5, name(S5, replace) title("5 year") xlab(,format(%3.1f)) wid(0.005)
  graph combine S1 S5, xcommon ycommon ///
  note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))
}       

       
predict h40_dep1 h40_dep5, hazard ci frame(hazpred, replace) per(1000) ///
                           timevar(0.1 5, step(0.1))                   ///
                           at1(dep 1 agediag 40)                       ///
                           at2(dep 5 agediag 40)

frame hazpred {
  twoway (line h40_dep1 h40_dep5 tt),                                     ///
         xtitle("Years from diagnosis")                                   ///
         ytitle("Mortality rate (per 1000 py)")                           ///
         ylabel(0(20)100)                                                 ///
         title("Predicted hazard rate for a 40 year old")                 ///
         legend(order(1 "Least deprived" 2 "Most deprived"))              ///
         note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))
}

frame hazpred: list  in 1/10, noobs

predict S40_dep1 S40_dep5, survival ci frame(survpred, replace)        ///
                           timevar(0 5, step(0.1))                     ///
                           at1(dep 1 agediag 40) at2(dep 5 agediag 40)
        
frame survpred {
  twoway (line S40_dep1 S40_dep5 tt),                               ///
         xtitle("Years from diagnosis")                             ///
         ytitle("Probability Alive")                                ///
         ylabel(0(0.2)1, format(%3.1f))                             ///
         title("Predicted Survival for a 40 year old")              ///
         legend(order(1 "Least deprived" 2 "Most deprived") pos(9)) ///
         note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))
}        

// predicting for a range of ages
capture frame drop agepred

frame create agepred
frame agepred {
  range agediag 18 50 33
  gen dep = .
  gen t5 = 5
  predict S_dep1 S_dep5, surv ci timevar(t5) merge   ///
         at1(dep 1, obsvalues) at2(dep 5, obsvalues)
}

frame agepred {
  twoway (line S_dep1 S_dep5 agediag)                                      ///
         (rarea S_dep1_lci S_dep1_uci agediag, pstyle(p1line) color(%30))  ///
         (rarea S_dep5_lci S_dep5_uci agediag, pstyle(p2line) color(%30))  ///
         , legend(order(1 "Least Deprived" 2 "Most deprived")              ///
         cols(1) pos(11))                                                  ///
         ylabel(0.4(0.1)1, format(%3.1f))                                  ///
         ytitle("Survival at 5 years")                                     ///
         xtitle("Age at diagnosis")                                    ///
         note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))
}
grinset t=5 r=5: hist agediag, freq

range tt 0 5 101
standsurv , survival at1(.) timevar(tt) ci atvar(Sm) frame(msurv, replace)

sts graph, noshow plotopts(lwidth(*3) lcolor(%60)) legend(on) ///
    note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))
frame msurv: addplot: line Sm tt, lcolor(%100) ///
    legend(order(1 "Kaplan-Meier" 2 "Model based"))




stpm3km
stpm3km, ///
  note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))

stpm3km agediag, groups(4) 
stpm3km agediag, groups(4) ///
  note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))

// Fit a more complex model
stpm3 i.dep @ns(agediag,df(3)), scale(lncumhazard) df(5) eform nolog 

stpm3km
stpm3km, ///
  note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))

stpm3km agediag, groups(4) 
stpm3km agediag, groups(4) ///
  note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))

